@@ -9,6 +9,10 @@ use strict;
 use warnings;
 package Net::SAML2::XML::Sig; use base qw(XML::Sig); 1;
 
+our $VERSION = '0.48';
+
+# ABSTRACT: Net::SAML2 subclass of XML::Sig
+
 __END__
 
 =pod
@@ -17,11 +21,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::XML::Sig
+Net::SAML2::XML::Sig - Net::SAML2 subclass of XML::Sig
 
 =head1 VERSION
 
-version 0.47
+version 0.48
 
 =head1 AUTHOR
 
